@@ -2,7 +2,7 @@
 #######################################################################
 """Product class for the Zope 3 based quota package
 
-$Id: quota.py 49891 2008-02-02 15:36:58Z cray $
+$Id: quota.py 50802 2008-02-21 11:27:20Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
@@ -115,9 +115,15 @@ class Quota(Contained,Persistent):
                 print "QuotaAddFailed:",msg
             else :
                 if self.max <= size:
-                    self.max = max(self.osz.values())
+                    try :
+                        self.max = max(self.osz.values())
+                    except ValueError :
+                        self.max = 0
                 if self.min >= size :
-                    self.min = min(self.osz.values())
+                    try :
+                        self.min = min(self.osz.values())
+                    except ValueError :
+                        self.min = 0                        
 
                 self.size-=size
                 self.count -= 1
