@@ -1,18 +1,20 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""QuotaAdapter class for the Zope 3 based ng.app.quota.quotaannotation package
+"""QuotaAnnotationAdapter script for the Zope 3 based
+ng.app.quota package
 
-$Id: quotaannotationadapter.py 49891 2008-02-02 15:36:58Z cray $
+$Id: quotaannotationadapter.py 50802 2008-02-21 11:27:20Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49891 $"
+__version__ = "$Revision: 50802 $"
 
 
 from zope.annotation.interfaces import IAnnotations
 from ng.app.quota.quota import Quota
 from ng.app.quota.interfaces import quotakey
 
+
 def QuotaAnnotationAdapter(context) :
     try :
         an = IAnnotations(context)[quotakey]
