@@ -1,17 +1,18 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""QuotaAdapter class for the Zope 3 based ng.app.quota.quotaannotation package
+"""QuotaAdapter class for the Zope 3 based ng.app.quota.quotahandle package
 
-$Id: quotautilities.py 49891 2008-02-02 15:36:58Z cray $
+$Id: quotautilities.py 50802 2008-02-21 11:27:20Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49891 $"
+__version__ = "$Revision: 50802 $"
 
 
 from zope.component import getUtilitiesFor
 from interfaces import IQuota
 
+
 class QuotaAdapter(object) :
 
     def __init__(self,context) :
@@ -29,4 +30,3 @@ class QuotaAdapter(object) :
     def handleRemoved(self,ob): 
         for quota in self.quotas :
             quota.handleRemoved(ob)
-
